@@ -335,10 +335,14 @@ def process_bulkstatus(df):
         df.loc[(df['BulkStatus'] == 1), 'is_FU'] = 1        
         df.drop(labels=['BulkStatus'],axis=1,inplace=True)
         logger.info('Deleted BulkStatus column')
-        logger.info(f' OOO: {df['is_OOO'].value_counts()}')
-        logger.info(f' NN: {df['is_NN'].value_counts()}')
-        logger.info(f' New: {df['is_New'].value_counts()}')
-        logger.info(f' FU: {df['is_FU'].value_counts()}')
+        logger.info('OOO')
+        logger.info(df['is_OOO'].value_counts())
+        logger.info('NN')
+        logger.info(df['is_NN'].value_counts())
+        logger.info('New')
+        logger.info(df['is_New'].value_counts())
+        logger.info('FU')
+        logger.info(df['is_FU'].value_counts())
     else:
         logger.info('Column not present')
     return df
